"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const cli_service_1 = require("./modules/cli/cli.service");
const node_version_service_1 = require("./modules/node-version/node.version.service");
const npm_dependency_version_service_1 = require("./modules/npm-dependency-version/npm.dependency.version.service");
const rate_limit_service_1 = require("./modules/rate-limit/rate.limit.service");
const presenter_service_1 = require("./modules/presenter/presenter.service");
const interfaces_1 = require("./modules/presenter/interfaces");
let AppService = class AppService {
    constructor(cliService, presenterService, rateLimitService, nodeVersionService, npmDependencyVersionService) {
        this.cliService = cliService;
        this.presenterService = presenterService;
        this.rateLimitService = rateLimitService;
        this.nodeVersionService = nodeVersionService;
        this.npmDependencyVersionService = npmDependencyVersionService;
    }
    main() {
        return __awaiter(this, void 0, void 0, function* () {
            const options = yield this.cliService.getProgramOptions();
            return this.run(options);
        });
    }
    run(options) {
        return __awaiter(this, void 0, void 0, function* () {
            this.setupPresenter(options);
            this.presenterService.showFiglet();
            this.presenterService.showGithubTokenInfo(options);
            const { package: packageName, node, rateLimit, token } = options;
            if (node) {
                return this.nodeCase(options);
            }
            else if (packageName) {
                return this.packageCase(options);
            }
            else if (rateLimit) {
                return this.showRateLimit(true, token);
            }
            else {
                this.presenterService.showError('Wrong input');
            }
        });
    }
    nodeCase(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const report = yield this.nodeVersionService.getReport(options);
            this.presenterService.showData(report, options);
            this.showRateLimit(false, options.token);
        });
    }
    packageCase(options) {
        return __awaiter(this, void 0, void 0, function* () {
            const report = yield this.npmDependencyVersionService.getReport(options);
            this.presenterService.showData(report, options);
            this.showRateLimit(false, options.token);
        });
    }
    showRateLimit(isMainInfo, token) {
        return __awaiter(this, void 0, void 0, function* () {
            const rateLimit = yield this.rateLimitService.getRateLimit(token);
            this.presenterService.showRateLimit(rateLimit, isMainInfo);
        });
    }
    setupPresenter(options) {
        const presentationMode = this.getPresentationMode(options);
        presenter_service_1.PresenterService.setMode(presentationMode);
    }
    getPresentationMode(options) {
        const { json, rawJson, csv } = options;
        switch (true) {
            case rawJson:
                return interfaces_1.PresentationMode.RAW_JSON;
            case json:
                return interfaces_1.PresentationMode.JSON;
            case csv:
                return interfaces_1.PresentationMode.CSV;
            default:
                return interfaces_1.PresentationMode.DEFAULT;
        }
    }
};
AppService = __decorate([
    common_1.Injectable(),
    __param(0, common_1.Optional()),
    __metadata("design:paramtypes", [cli_service_1.CliService,
        presenter_service_1.PresenterService,
        rate_limit_service_1.RateLimitService,
        node_version_service_1.NodeVersionService,
        npm_dependency_version_service_1.NpmDependencyVersionService])
], AppService);
exports.AppService = AppService;
//# sourceMappingURL=app.service.js.map