"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
const yargs = require("yargs");
const common_1 = require("@nestjs/common");
const default_1 = require("../../config/default");
let CommanderService = class CommanderService {
    getProgramOptions() {
        const argv = yargs
            .usage('Search npm packages in all org repos. You can set GITHUB_TOKEN env var, if public access restricted')
            .help('help')
            .alias('h', 'help')
            .showHelpOnFail(false, 'Specify --help for available options')
            .version()
            .alias('v', 'version')
            .describe('v', 'show version information')
            .option('org', {
            alias: 'o',
            describe: 'github org where search applied',
            type: 'string',
        })
            .option('user', {
            alias: 'u',
            describe: 'github user where search applied',
            type: 'string',
        })
            .option('repos', {
            alias: 'r',
            describe: 'github user where search applied',
            type: 'array',
        })
            .option('package', {
            alias: 'p',
            describe: 'package to search',
            type: 'string',
        })
            .option('deps', {
            describe: 'disable search in "dependencies" package.json field',
            default: default_1.DEFAULT.deps,
            type: 'boolean',
        })
            .option('dev-deps', {
            describe: 'disable search in "devDependencies" package.json field',
            default: default_1.DEFAULT.devDeps,
            type: 'boolean',
        })
            .option('peer-deps', {
            describe: 'disable search in "peerDependencies" package.json field',
            default: default_1.DEFAULT.peerDeps,
            type: 'boolean',
        })
            .option('yarn-lock', {
            describe: 'disable search in yarn.lock',
            default: default_1.DEFAULT.yarnLock,
            type: 'boolean',
        })
            .option('package-lock', {
            describe: 'disable search in package-lock.json',
            default: default_1.DEFAULT.packageLock,
            type: 'boolean',
        })
            .option('node', {
            alias: 'n',
            describe: 'search node version based on .nvmrc and package.json engines',
        })
            .options('nvm', {
            describe: 'disable search in .nvmrc',
            default: default_1.DEFAULT.nvm,
            type: 'boolean',
        })
            .options('engines', {
            describe: 'disable search in package.json engines',
            default: default_1.DEFAULT.engines,
            type: 'boolean',
        })
            .option('rate-limit', {
            alias: 'l',
            describe: 'show rate limit',
        })
            .option('skip-empty', {
            describe: 'skip repo, if package/node not found',
            default: default_1.DEFAULT.skipEmpty,
            type: 'boolean',
        })
            .option('skip-error', {
            describe: 'skip repo, if error with such code occured',
            default: default_1.DEFAULT.skipError,
            type: 'array'
        })
            .option('raw-json', {
            describe: 'show output as json without whitespaces',
            default: default_1.DEFAULT.rawJson,
            type: 'boolean',
        })
            .option('json', {
            describe: 'show output as prettified json',
            default: default_1.DEFAULT.json,
            type: 'boolean',
        })
            .option('csv', {
            describe: 'show output as csv',
            default: default_1.DEFAULT.csv,
            type: 'boolean',
        })
            .option('token', {
            alias: 't',
            describe: 'token to auth on github. Env var GITHUB_TOKEN strictly prefered',
            default: default_1.DEFAULT.token,
            type: 'string'
        })
            .group(['user', 'org', 'repo'], 'Owner:')
            .group(['package', 'deps', 'dev-deps', 'peer-deps', 'yarn-lock', 'package-lock'], 'NPM package:')
            .group(['node', 'nvm', 'engines'], 'Node version:')
            .check(this.validation)
            .argv;
        return argv;
    }
    validation(argv) {
        const { user, org } = argv;
        if (user && org) {
            throw new Error('You should specify either user or org. Not both');
        }
        return true;
    }
};
CommanderService = __decorate([
    common_1.Injectable()
], CommanderService);
exports.CommanderService = CommanderService;
//# sourceMappingURL=commander.service.js.map