"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const inquirer = require("inquirer");
const common_1 = require("@nestjs/common");
let InquirerService = class InquirerService {
    promptOwner() {
        return __awaiter(this, void 0, void 0, function* () {
            const { owner } = yield inquirer.prompt([
                {
                    type: 'list',
                    name: 'owner',
                    message: `Do you want to apply search for user's or for org's repos?`,
                    choices: [
                        'User',
                        'Org',
                    ]
                },
            ]);
            switch (owner) {
                case 'User':
                    return this.promptUser();
                case 'Org':
                    return this.promptOrg();
                default:
                    return {};
            }
        });
    }
    promptMode() {
        return __awaiter(this, void 0, void 0, function* () {
            const { mode } = yield inquirer.prompt([
                {
                    type: 'list',
                    name: 'mode',
                    message: `What operation are you looking for?`,
                    choices: [
                        { name: 'Get node versions', value: 'node' },
                        { name: 'Get npm package versions', value: 'package' },
                        { name: 'Get rate limits info', value: 'rate-limits' },
                    ]
                },
            ]);
            switch (mode) {
                case 'node':
                    return Object.assign({ node: true }, yield this.promptNode());
                case 'package':
                    return this.promptPackage();
                case 'rate-limits':
                    return {
                        rateLimit: true,
                    };
                default:
                    return {};
            }
        });
    }
    promptNode() {
        return __awaiter(this, void 0, void 0, function* () {
            const { nvm, engines } = yield inquirer.prompt([
                {
                    type: 'list',
                    name: 'nvm',
                    message: `Do you want to apply search in .nvrc files?`,
                    default: true,
                    choices: [
                        { name: 'Yes', value: true },
                        { name: 'No', value: false },
                    ]
                },
                {
                    type: 'list',
                    name: 'engines',
                    message: `Do you want to apply search in package.json engines?`,
                    default: true,
                    choices: [
                        { name: 'Yes', value: true },
                        { name: 'No', value: false },
                    ]
                }
            ]);
            return { nvm, engines };
        });
    }
    promptPackage() {
        return __awaiter(this, void 0, void 0, function* () {
            const { package: packageName, packageJsonFields, packageLock, yarnLock } = yield inquirer.prompt([
                {
                    type: 'input',
                    name: 'package',
                    message: `What npm package do you want to search?`
                },
                {
                    type: 'checkbox',
                    name: 'packageJsonFields',
                    message: `Do you want to apply search in following package.json sections?`,
                    choices: [
                        { name: 'dependencies', value: 'deps', checked: true },
                        { name: 'devDependencies', value: 'devDeps', checked: true },
                        { name: 'peerDependencies', value: 'peerDeps', checked: true },
                    ]
                },
                {
                    type: 'list',
                    name: 'packageLock',
                    message: `Do you want to apply search in package-lock.json?`,
                    default: true,
                    choices: [
                        { name: 'Yes', value: true },
                        { name: 'No', value: false },
                    ]
                },
                {
                    type: 'list',
                    name: 'yarnLock',
                    message: `Do you want to apply search in yarn.lock?`,
                    default: true,
                    choices: [
                        { name: 'Yes', value: true },
                        { name: 'No', value: false },
                    ]
                }
            ]);
            return {
                package: packageName,
                deps: packageJsonFields.includes('deps'),
                devDeps: packageJsonFields.includes('devDeps'),
                peerDeps: packageJsonFields.includes('peerDeps'),
                packageLock,
                yarnLock,
            };
        });
    }
    promptUser() {
        return __awaiter(this, void 0, void 0, function* () {
            const { user } = yield inquirer.prompt([
                {
                    type: 'input',
                    name: 'user',
                    message: `Enter github username`,
                },
            ]);
            return { user };
        });
    }
    promptOrg() {
        return __awaiter(this, void 0, void 0, function* () {
            const { org } = yield inquirer.prompt([
                {
                    type: 'input',
                    name: 'org',
                    message: `Enter github org name`,
                },
            ]);
            return { org };
        });
    }
};
InquirerService = __decorate([
    common_1.Injectable()
], InquirerService);
exports.InquirerService = InquirerService;
//# sourceMappingURL=inquirer.service.js.map