"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const lockfile = require("@yarnpkg/lockfile");
const octokit_service_1 = require("../octokit/octokit.service");
let YarnLockVersionService = class YarnLockVersionService {
    constructor(octokitService) {
        this.octokitService = octokitService;
        this.REGEXP = /^(.+)\@(.+)$/;
    }
    getVersion(owner, repo, packageName, token) {
        return __awaiter(this, void 0, void 0, function* () {
            const doc = yield this.getYarnLock(owner, repo, token);
            if (doc.type !== 'success') {
                return null;
            }
            const dependencies = Object.keys(doc.object);
            const versionHash = dependencies
                .reduce((acc, dep) => {
                const [full, depName, depVersion] = dep.match(this.REGEXP);
                if (depName === packageName) {
                    acc[depVersion] = doc.object[dep].version;
                }
                return acc;
            }, {});
            const versionUsed = [];
            const versions = dependencies
                .map(dep => {
                const requiredVersion = doc.object[dep].dependencies && doc.object[dep].dependencies[packageName];
                if (!requiredVersion) {
                    return null;
                }
                const version = versionHash[requiredVersion];
                versionUsed.push(version);
                return {
                    host: dep,
                    version,
                };
            })
                .filter(x => x);
            const versionsUnusedInDeps = Object.values(versionHash).filter(v => !versionUsed.includes(v));
            const allVersions = [
                ...versions,
                ...versionsUnusedInDeps.map(version => ({
                    host: '<root>',
                    version,
                }))
            ];
            return allVersions.map(({ host, version }) => `${version} for ${host}`);
        });
    }
    getYarnLock(owner, repo, token) {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                const content = yield this.octokitService.getFileContent(owner, repo, 'yarn.lock', token);
                return lockfile.parse(content);
            }
            catch (e) {
                return null;
            }
        });
    }
};
YarnLockVersionService = __decorate([
    common_1.Injectable(),
    __metadata("design:paramtypes", [octokit_service_1.OctokitService])
], YarnLockVersionService);
exports.YarnLockVersionService = YarnLockVersionService;
//# sourceMappingURL=yarn.lock.version.service.js.map